from django.conf import settings
from django.forms.utils import flatatt
from django.template import Library

from ..utils import jquery_path

register = Library()


@register.simple_tag
def jquery_script():
    return '<script{0}></script>'.format(flatatt({
        'type': 'text/javascript',
        'src': settings.STATIC_URL + jquery_path,
    }))



#!/usr/bin/env python
"""
Install django-jquery-js using setuptools
"""

from jquery import __version__

try:
    from setuptools import setup, find_packages
except ImportError:
    from ez_setup import use_setuptools
    use_setuptools()
    from setuptools import setup, find_packages

setup(
    name='django-jquery-js',
    version=__version__,
    description='jQuery, bundled up so apps can depend upon it',
    author='Tim Heap',
    author_email='tim@ionata.com.au',
    url='https://bitbucket.org/tim_heap/django-jquery',

    install_requires=['Django>=1.4'],
    zip_safe=False,

    packages=find_packages(),

    include_package_data=True,
    package_data={ },

    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Framework :: Django',
        'License :: OSI Approved :: MIT License',
    ],
)
